import re
from run import (Module, NullTask, RenderTask, SubprocessTask, module,
                 FindVar, ValueVar)

class PythonPackgramModule(Module):
    
    #Tasks
    
    build = NullTask(
        require=[
            'build_gitignore',                 
            'build_travis',
            'build_manifest',
            'build_readme',
            'build_requirements',
            'build_setup',
            'build_docs',                                                            
        ],
    )
    
    build_docs = SubprocessTask(
        prefix='sphinx-build -b html -d docs/doctrees _sources/docs docs/html',
    )
             
    build_gitignore = RenderTask(
        source='_sources/.gitignore',
        target='.gitignore',        
    )
    
    build_travis = RenderTask(
        source='_sources/.travis.yml',
        target='.travis.yml',
    )
    
    build_manifest = RenderTask(
        source='_sources/MANIFEST.in',
        target='MANIFEST.in',
    )            
    
    build_readme = RenderTask(
        source='_sources/README.rst',
        target='README.rst',
    ) 
    
    build_requirements = RenderTask(
        source='_sources/requirements.txt',
        target='requirements.txt',
    ) 
    
    build_setup = RenderTask(
        source='_sources/setup.tpl',
        target='setup.py',
    )
    
    #Vars
     
    long_description = FindVar(
        filename='README.rst',
        maxdepth=1,
        getfirst=True,
    )
    
    pypi_name = ValueVar(
        value=module().name,
    )
    
    version = FindVar(
        string=re.compile(r'(?:major|minor|micro|level)\s*=\s*[\'"]?(\w*)[\'"]?'),
        filename='version.py',
        maxdepth=2,
        reducers=[
            lambda values: [value for value in values if value != 'final'],
            lambda values: '.'.join(values),
        ],
    )